@@ -391,7 +391,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.82'
+__version__ = '0.2.83'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -1540,7 +1540,9 @@ class MainAppBase(ConsoleApp, ABC):
         :param wid:             widget to determine visibility of.
         :return:                True if widget is visible (or visibility cannot be determined), False if hidden.
         """
-        return bool(wid.width and wid.height and getattr(wid, 'visible', True) and getattr(wid, 'opacity', True))
+        return bool(wid.width and wid.height and
+                    getattr(wid, 'visible', True) in (True, None) and   # containers/BoxLayout.visible is None ?!?!?
+                    getattr(wid, 'opacity', True))
 
     def win_pos_size_change(self, *win_pos_size):
         """ screen resize handler (called on window resize or when app will exit/stop via closed event.
